<?php declare(strict_types=1);

namespace Infomaker\ProjectPlugin\Handler;

use Infomaker\Everyware\Support\Collection;
use Infomaker\Everyware\Support\Str;
use Infomaker\Everyware\Twig\View;

class JsonImporter
{

    /**
     * @var string
     */
    protected $submit_name = 'imported-data';

    /**
     * JsonImporter constructor.
     *
     * @param string $submit_name
     */
    public function __construct(string $submit_name = '')
    {
        if(Str::notEmpty($submit_name)) {
            $this->submit_name = Str::slug($submit_name);
        }
    }

    /**
     * Determine if data has been imported
     *
     * @return bool
     */
    public function isImported(): bool
    {
        return isset($_POST[$this->submit_name]);
    }

    /**
     * Function for adding imported sections to the existing list
     *
     * @return array
     */
    public function getJson(): array
    {
        if($this->isImported()) {
            $json = Collection::make($_POST)->get($this->submit_name, '');
            $data = json_decode(stripslashes($json), true);

            return $data !== null ? array_filter($data) : [];
        }

        return [];
    }

    /**
     * Generate an Import export module
     *
     * @param string $import
     * @param string $export
     * @param string $template
     *
     * @return string
     * @throws \Twig_Error_Loader
     * @throws \Twig_Error_Runtime
     * @throws \Twig_Error_Syntax
     */
    public function generate(string $import = null, string $export = null, $template = null): string
    {

        return View::generate($template ?? '@projectPlugin/utilities/import-export', [
            'field_name' => $this->submit_name,
            'import'     => $import ?? '',
            'export'     => $export ?? '',
        ]);
    }
}
